"""Commands available for workflows."""

from __future__ import annotations

from os import sep
from pathlib import Path

from rwx import ps

from spcd.ci import project, projects
from spcd.shell import env
from spcd.util import browse


def spcd_browse_workspace() -> None:
    """Browse the current workspace for the project."""
    browse(project.root)


def spcd_build_project() -> None:
    """Perform the actual building process."""
    for extension in ("py", "sh"):
        path = project.root / f"build.{extension}"
        if path.exists():
            ps.run(str(path))
            break


def spcd_check_project() -> None:
    """Check the project for anything wrong."""
    ps.run(
        "ruff",
        "check",
        ("--ignore", "D203,D213"),
        "--isolated",
        ("--select", "ALL"),
    )
    ps.run(
        "ruff",
        "format",
        "--diff",
        "--isolated",
        ("--line-length", "80"),
    )


def spcd_synchronize(
    source: str | None = None,
    target: str | None = None,
) -> None:
    """Synchronize output towards a target.

    :param source: where to deploy from
    :type source: str | None
    :param target: where to deploy to
    :type target: str | None
    """
    if not target:
        user = "cd"
        host = env.SPCD_PROJECT_PATH
        root = Path(sep) / user / projects.group / project.name / project.branch
        target = f"{user}@{host}:{root}"
    if not source:
        source = "out"
    ps.run(
        "rsync",
        "--archive",
        "--delete-before",
        "--verbose",
        f"{source}{sep}",
        f"{target}{sep}",
    )
